/* ============================================================
 * File  : property.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include "property.h"

property::property ( QWidget * parent )
    : QFrame(parent)
{
	dragPosition = QPoint(0,0);
        myfont.setPixelSize ( 12 );
	myfont.setBold(true);

        QPalette mypal = QApplication::palette();
        wg_color_1 = mypal.color(QPalette::Normal, QPalette::Text);
        wg_color_2 = mypal.color(QPalette::Normal, QPalette::Light);
        wg_color_3 = mypal.color(QPalette::Normal, QPalette::Midlight);
        wg_color_4 = mypal.color(QPalette::Normal, QPalette::Dark);
        wg_color_5 = mypal.color(QPalette::Normal, QPalette::Shadow);
        //wg_color_5.setAlpha(220);

        QRadialGradient Gradient1(this->width()/2,this->height(),this->width()/2,this->width()/2,this->height()/2);
        Gradient1.setColorAt(0.0, wg_color_3.dark(95));
        Gradient1.setColorAt(0.5, wg_color_3);
        Gradient1.setColorAt(1.0, wg_color_4);

        pntgrad = Gradient1;

        QGraphicsDropShadowEffect *myeffect = new QGraphicsDropShadowEffect();
        myeffect->setXOffset(1);
        myeffect->setYOffset(1);
        myeffect->setBlurRadius(2.0);
        this->setAttribute(Qt::WA_TranslucentBackground, true);
        this->setGraphicsEffect(myeffect);
}

void property::f_resize(QResizeEvent *)
{
    QRadialGradient Gradient1(this->width()/2,this->height(),this->width(),this->width()/2,this->height()/2);
    Gradient1.setColorAt(0.0, wg_color_3.dark(95));
    Gradient1.setColorAt(0.5, wg_color_3);
    Gradient1.setColorAt(1.0, wg_color_4);

    pntgrad = Gradient1;
}

void property::mouseMoveEvent(QMouseEvent *event)
{
	if (!(event->buttons() & Qt::LeftButton) ) return;
	if ( dragPosition == QPoint(0,0) )
	{
	}
	else
	{
		move(event->globalPos() - dragPosition);
	}
}

void property::mousePressEvent ( QMouseEvent * event ) 
{
	dragPosition = event->globalPos() - frameGeometry().topLeft();
        this->raise();
}

void property::mouseReleaseEvent ( QMouseEvent * ) 
{
	dragPosition = QPoint(0,0);
}

void property::paintEvent(QPaintEvent *)
{
	QPainter p;
	p.begin(this);
	p.setRenderHint(QPainter::Antialiasing,true);
        p.setPen(wg_color_2); //Qt::NoPen);
        p.setBrush(wg_color_2);
        p.drawRoundedRect(1, 1, this->width()-2, this->height()-2,6,6,Qt::AbsoluteSize);

        p.setBrush(pntgrad);
        p.drawRoundedRect(1, 1, this->width()-2, this->height()-2,2,2,Qt::AbsoluteSize);
        //p.setCompositionMode();
        //p.drawLine(5,24,this->width()-10,24);
	if ( this->statusTip() != "" )
	{
		p.setFont(myfont);
                p.setPen(wg_color_1);
                p.drawText(QRect(5,4,this->width()-10,20), Qt::AlignCenter,this->statusTip());
	}

	p.end();
}

